@@ -2,9 +2,9 @@ package Catmandu::Util;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2012';
+our $VERSION = '1.2025';
 
-use Exporter qw(import);
+use Exporter      qw(import);
 use Sub::Quote    ();
 use Scalar::Util  ();
 use List::Util    ();
@@ -259,8 +259,8 @@ sub get_data {
     if (is_array_ref($data)) {
         if    ($key eq '$first') {return unless @$data; $key = 0}
         elsif ($key eq '$last')  {return unless @$data; $key = @$data - 1}
-        elsif ($key eq '*') {return @$data}
-        if (array_exists($data, $key)) {
+        elsif ($key eq '*')      {return @$data}
+        if    (array_exists($data, $key)) {
             return $data->[$key];
         }
         return;
@@ -297,8 +297,8 @@ sub delete_data {
     if (is_array_ref($data)) {
         if    ($key eq '$first') {return unless @$data; $key = 0}
         elsif ($key eq '$last')  {return unless @$data; $key = @$data - 1}
-        elsif ($key eq '*') {return splice @$data, 0, @$data}
-        if (array_exists($data, $key)) {
+        elsif ($key eq '*')      {return splice @$data, 0, @$data}
+        if    (array_exists($data, $key)) {
             return splice @$data, $key, 1;
         }
         return;
@@ -333,10 +333,10 @@ sub data_at {
                     @$data;
             }
             else {
-                if    ($key eq '$first')   {$key                        = 0}
-                elsif ($key eq '$last')    {$key                        = -1}
+                if    ($key eq '$first')   {$key = 0}
+                elsif ($key eq '$last')    {$key = -1}
                 elsif ($key eq '$prepend') {unshift @$data, undef; $key = 0}
-                elsif ($key eq '$append') {push @$data, undef; $key = @$data}
+                elsif ($key eq '$append')  {push @$data, undef; $key = @$data}
                 is_integer($key) || return;
                 if ($create && @$path) {
                     $data = $data->[$key] ||= is_integer($path->[0])
@@ -461,12 +461,15 @@ sub check_different {
 }
 
 sub is_bool {
-    Scalar::Util::blessed($_[0])
-        && ($_[0]->isa('boolean')
-        || $_[0]->isa('Types::Serialiser::Boolean')
-        || $_[0]->isa('JSON::XS::Boolean')
-        || $_[0]->isa('Cpanel::JSON::XS::Boolean')
-        || $_[0]->isa('JSON::PP::Boolean'));
+    my $obj = $_[0];
+    Scalar::Util::blessed($obj) || return 0;
+    eval {
+               $obj->isa('boolean')
+            || $obj->isa('Types::Serialiser::Boolean')
+            || $obj->isa('JSON::XS::Boolean')
+            || $obj->isa('Cpanel::JSON::XS::Boolean')
+            || $obj->isa('JSON::PP::Boolean');
+    } // 0;
 }
 
 sub is_integer {
@@ -514,7 +517,9 @@ sub check_maybe_able {
 sub is_instance {
     my $obj = shift;
     Scalar::Util::blessed($obj) || return 0;
-    $obj->isa($_)               || return 0 for @_;
+    for my $pkg (@_) {
+        eval {$obj->isa($pkg)} || return 0;
+    }
     1;
 }
 
@@ -532,7 +537,8 @@ sub check_maybe_instance {
         'should be undef or instance of ' . array_to_sentence(\@_));
 }
 
-Data::Util::install_subroutine(__PACKAGE__,
+Data::Util::install_subroutine(
+    __PACKAGE__,
     hash_merge    => \&Hash::Merge::Simple::merge,
     is_same       => \&Data::Compare::Compare,
     is_invocant   => \&Data::Util::is_invocant,
